@@ -3,8 +3,9 @@ Main interface for codepipeline service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codepipeline import (
+    from mypy_boto3_codepipeline import (
         Client,
         CodePipelineClient,
         ListActionExecutionsPaginator,
@@ -13,7 +14,7 @@ Usage::
         ListPipelinesPaginator,
         ListTagsForResourcePaginator,
         ListWebhooksPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -26,6 +27,7 @@ Usage::
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     list_webhooks_paginator: ListWebhooksPaginator = client.get_paginator("list_webhooks")
+    ```
 """
 from mypy_boto3_codepipeline.client import CodePipelineClient as Client, CodePipelineClient
 from mypy_boto3_codepipeline.paginator import (
