@@ -3,13 +3,15 @@ Main interface for codepipeline service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codepipeline import CodePipelineClient
+    from mypy_boto3_codepipeline import CodePipelineClient
 
     session = boto3.Session()
 
     client: CodePipelineClient = boto3.client("codepipeline")
     session_client: CodePipelineClient = session.client("codepipeline")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
