@@ -3,8 +3,11 @@ Main interface for codepipeline service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.codepipeline import (
+
+    from mypy_boto3_codepipeline import CodePipelineClient
+    from mypy_boto3_codepipeline import (
         ListActionExecutionsPaginator,
         ListActionTypesPaginator,
         ListPipelineExecutionsPaginator,
@@ -21,6 +24,7 @@ Usage::
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     list_webhooks_paginator: ListWebhooksPaginator = client.get_paginator("list_webhooks")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
